==> libraries_delay_load-2.0.2.tar.gz: libraries_delay_load/src/Entity/JsDelayStrategy.php <==
<?php

namespace Drupal\libraries_delay_load\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\libraries_delay_load\JsDelayStrategyInterface;

/**
 * Defines the JsDelayStrategy entity.
 *
 * @ConfigEntityType(
 *   id = "js_delay_strategy",
 *   label = @Translation("Libraries Delay Load"),
 *   handlers = {
 *     "list_builder" = "Drupal\libraries_delay_load\Controller\JsDelayStrategyListBuilder",
 *     "form" = {
 *       "add" = "Drupal\libraries_delay_load\Form\JsDelayStrategyForm",
 *       "edit" = "Drupal\libraries_delay_load\Form\JsDelayStrategyForm",
 *       "delete" = "Drupal\libraries_delay_load\Form\JsDelayStrategyDeleteForm",
 *     }
 *   },
 *   config_prefix = "libraries_delay_load",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "weight" = "weight",
 *     "excluded" = "excluded",
 *     "groups" = "groups",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "weight",
 *     "excluded",
 *     "groups",
 *   },
 *   links = {
 *     "edit-form" = "/admin/config/performance/libraries_delay_load/js_strategies/{libraries_delay_load}",
 *     "delete-form" = "/admin/config/performance/libraries_delay_load/js_strategies/{libraries_delay_load}/delete",
 *   }
 * )
 */
class JsDelayStrategy extends ConfigEntityBase implements JsDelayStrategyInterface {

  /**
   * The JsDelayStrategy ID.
   *
   * @var string
   */
  public $id;

  /**
   * The JsDelayStrategy label.
   *
   * @var string
   */
  public $label;

  /**
   * The JsDelayStrategy weight.
   *
   * @var int
   */
  public $weight;

  /**
   * The JsDelayStrategy list of excluded javascripts.
   *
   * @var string
   */
  public $excluded;

  /**
   * The JsDelayStrategy groups of delayed javascripts.
   *
   * @var array
   */
  public $groups;

}

==> libraries_delay_load-2.0.3.tar.gz: libraries_delay_load/src/Entity/JsDelayStrategy.php <==
<?php

namespace Drupal\libraries_delay_load\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\libraries_delay_load\JsDelayStrategyInterface;

/**
 * Defines the JsDelayStrategy entity.
 *
 * @ConfigEntityType(
 *   id = "js_delay_strategy",
 *   label = @Translation("Libraries Delay Load"),
 *   handlers = {
 *     "list_builder" = "Drupal\libraries_delay_load\Controller\JsDelayStrategyListBuilder",
 *     "form" = {
 *       "add" = "Drupal\libraries_delay_load\Form\JsDelayStrategyForm",
 *       "edit" = "Drupal\libraries_delay_load\Form\JsDelayStrategyForm",
 *       "delete" = "Drupal\libraries_delay_load\Form\JsDelayStrategyDeleteForm",
 *     }
 *   },
 *   config_prefix = "js_delay_strategy",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "weight" = "weight",
 *     "excluded" = "excluded",
 *     "groups" = "groups",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "weight",
 *     "excluded",
 *     "groups",
 *   },
 *   links = {
 *     "edit-form" = "/admin/config/performance/libraries_delay_load/js_strategies/{libraries_delay_load}",
 *     "delete-form" = "/admin/config/performance/libraries_delay_load/js_strategies/{libraries_delay_load}/delete",
 *   }
 * )
 */
class JsDelayStrategy extends ConfigEntityBase implements JsDelayStrategyInterface {

  /**
   * The JsDelayStrategy ID.
   *
   * @var string
   */
  public $id;

  /**
   * The JsDelayStrategy label.
   *
   * @var string
   */
  public $label;

  /**
   * The JsDelayStrategy weight.
   *
   * @var int
   */
  public $weight;

  /**
   * The JsDelayStrategy list of excluded javascripts.
   *
   * @var string
   */
  public $excluded;

  /**
   * The JsDelayStrategy groups of delayed javascripts.
   *
   * @var array
   */
  public $groups;

}
